@@ -26,27 +26,27 @@ class Prog():
 
     def _check_stream(self):
         """ Determines which output stream (stdout, stderr, or custom) to use. """
-        
-        try:
-            if self.stream == 1 and os.isatty(sys.stdout.fileno()):
-                self._stream_out = sys.stdout.write
-                self._stream_flush = sys.stdout.flush
-            elif self.stream == 2 and os.isatty(sys.stderr.fileno()):
-                self._stream_out = sys.stderr.write
-                self._stream_flush = sys.stderr.flush
-        except UnsupportedOperation: # a fix for IPython notebook "IOStream has no fileno."
-            if self.stream == 1:
-                self._stream_out = sys.stdout.write
-                self._stream_flush = sys.stdout.flush
-            elif self.stream == 2:
-                self._stream_out = sys.stderr.write
-                self._stream_flush = sys.stderr.flush
-        else: 
-            if self.stream is not None and hasattr(self.stream, 'write'):
-                self._stream_out = self.stream.write
-                self._stream_flush = self.stream.flush
+        if self.stream:
+            try:
+                if self.stream == 1 and os.isatty(sys.stdout.fileno()):
+                    self._stream_out = sys.stdout.write
+                    self._stream_flush = sys.stdout.flush
+                elif self.stream == 2 and os.isatty(sys.stderr.fileno()):
+                    self._stream_out = sys.stderr.write
+                    self._stream_flush = sys.stderr.flush
+            except UnsupportedOperation:  # a fix for IPython notebook "IOStream has no fileno."
+                if self.stream == 1:
+                    self._stream_out = sys.stdout.write
+                    self._stream_flush = sys.stdout.flush
+                elif self.stream == 2:
+                    self._stream_out = sys.stderr.write
+                    self._stream_flush = sys.stderr.flush
             else:
-                print('Warning: No valid output stream.')
+                if self.stream is not None and hasattr(self.stream, 'write'):
+                    self._stream_out = self.stream.write
+                    self._stream_flush = self.stream.flush
+        else:
+            print('Warning: No valid output stream.')
 
 
 
